@@ -5,7 +5,7 @@ from datetime import datetime, timedelta
 from notedrive.others.github.utils import (all_file_to_github,
                                            upload_data_to_github)
 from noteread.legado.shelf.base import BookSource, BookSourceCorrect
-from notetool.tool.pyrss import RSS2, RSSItem
+from noteread.rss import RSSItem, RssV2
 
 book = BookSource(lanzou_fid=4147049)
 book_correct = BookSourceCorrect(lanzou_fid=4147049)
@@ -103,17 +103,17 @@ def data2xml(repo='notechats/notefile', git_dir='notechats/noteread'):
             link=link,
             description=_file,
             # guid=PyRSS2Gen.Guid("https://github.com/notechats/notefile/tree/master/notechats/noteread"),
-            pubDate=date)
+            pub_date=date)
         items.append(item)
 
-    rss = RSS2(
+    rss = RssV2(
         title="yuedu feed",
         link="https://github.com/notechats/notefile/tree/master/notechats/noteread",
         description="阅读的书源",
-        lastBuildDate=datetime.now(),
-        items=items)
+        last_build_date=datetime.now(),
+        item_list=items)
 
-    res = rss.to_xml(encoding='UTF-8')
+    res = rss.write_xml_to_str(encoding='UTF-8')
     git_path = f"{git_dir}/legado-source.xml"
 
     upload_data_to_github(res, git_path, repo)
